@@ -16,6 +16,7 @@ const urlUtils = require('@joplin/lib/urlUtils');
 const ReactTooltip = require('react-tooltip');
 const { connect } = require('react-redux');
 import shared from '@joplin/lib/components/shared/note-screen-shared';
+import getHelpMessage from '@joplin/lib/components/shared/NoteRevisionViewer/getHelpMessage';
 import shim, { MessageBoxType } from '@joplin/lib/shim';
 import { RefObject, useCallback, useRef, useState } from 'react';
 import useQueuedAsyncEffect from '@joplin/lib/hooks/useQueuedAsyncEffect';
@@ -23,6 +24,7 @@ import useMarkupToHtml from './hooks/useMarkupToHtml';
 import useAsyncEffect from '@joplin/lib/hooks/useAsyncEffect';
 import { ScrollbarSize } from '@joplin/lib/models/settings/builtInMetadata';
 import { focus } from '@joplin/lib/utils/focusHandler';
+import useDeleteHistoryClick from '@joplin/lib/components/shared/NoteRevisionViewer/useDeleteHistoryClick';
 
 interface Props {
 	themeId: number;
@@ -30,6 +32,7 @@ interface Props {
 	onBack: ()=> void;
 	customCss: string;
 	scrollbarSize: ScrollbarSize;
+	fontFamily: string;
 }
 
 const useNoteContent = (
@@ -39,6 +42,7 @@ const useNoteContent = (
 	themeId: number,
 	customCss: string,
 	scrollbarSize: ScrollbarSize,
+	fontFamily: string,
 ) => {
 	const [note, setNote] = useState<NoteEntity>(null);
 
@@ -48,6 +52,7 @@ const useNoteContent = (
 		plugins: {},
 		whiteBackgroundNoteRendering: false,
 		scrollbarSize,
+		baseFontFamily: fontFamily,
 	});
 
 	useAsyncEffect(async (event) => {
@@ -77,7 +82,7 @@ const useNoteContent = (
 	return note;
 };
 
-const NoteRevisionViewerComponent: React.FC<Props> = ({ themeId, noteId, onBack, customCss, scrollbarSize }) => {
+const NoteRevisionViewerComponent: React.FC<Props> = ({ themeId, noteId, onBack, customCss, scrollbarSize, fontFamily }) => {
 	const helpButton_onClick = useCallback(() => {}, []);
 	const viewerRef = useRef<NoteViewerControl|null>(null);
 	const revisionListRef = useRef<HTMLSelectElement|null>(null);
@@ -85,8 +90,11 @@ const NoteRevisionViewerComponent: React.FC<Props> = ({ themeId, noteId, onBack,
 	const [revisions, setRevisions] = useState<RevisionEntity[]>([]);
 	const [currentRevId, setCurrentRevId] = useState('');
 	const [restoring, setRestoring] = useState(false);
+	const [deleting, setDeleting] = useState(false);
 
-	const note = useNoteContent(viewerRef, currentRevId, revisions, themeId, customCss, scrollbarSize);
+	const note = useNoteContent(
+		viewerRef, currentRevId, revisions, themeId, customCss, scrollbarSize, fontFamily,
+	);
 
 	const viewer_domReady = useCallback(async () => {
 		// this.viewerRef_.current.openDevTools();
@@ -105,6 +113,17 @@ const NoteRevisionViewerComponent: React.FC<Props> = ({ themeId, noteId, onBack,
 		await shim.showMessageBox(RevisionService.instance().restoreSuccessMessage(note), { type: MessageBoxType.Info });
 	}, [note]);
 
+	const resetScreenState = useCallback(() => {
+		setRevisions([]);
+		setCurrentRevId(null);
+	}, []);
+
+	const deleteHistoryButton_onClick = useDeleteHistoryClick({
+		noteId: note?.id,
+		setDeleting,
+		resetScreenState,
+	});
+
 	const backButton_click = useCallback(() => {
 		if (onBack) onBack();
 	}, [onBack]);
@@ -163,7 +182,8 @@ const NoteRevisionViewerComponent: React.FC<Props> = ({ themeId, noteId, onBack,
 	}
 
 	const restoreButtonTitle = _('Restore');
-	const helpMessage = _('Click "%s" to restore the note. It will be copied in the notebook named "%s". The current version of the note will not be replaced or modified.', restoreButtonTitle, RevisionService.instance().restoreFolderTitle());
+	const deleteHistoryButtonTitle = _('Delete history');
+	const helpMessage = getHelpMessage(restoreButtonTitle);
 
 	const titleInput = (
 		<div className='revision-viewer-title'>
@@ -177,6 +197,9 @@ const NoteRevisionViewerComponent: React.FC<Props> = ({ themeId, noteId, onBack,
 			<button disabled={!revisions.length || restoring} onClick={importButton_onClick} className='restore'style={{ ...theme.buttonStyle, marginLeft: 10, height: theme.inputStyle.height }}>
 				{restoreButtonTitle}
 			</button>
+			<button disabled={!revisions.length || deleting} onClick={deleteHistoryButton_onClick} className='deleteHistory'style={{ ...theme.buttonStyle, marginLeft: 10, height: theme.inputStyle.height }}>
+				{deleteHistoryButtonTitle}
+			</button>
 			<HelpButton tip={helpMessage} id="noteRevisionHelpButton" onClick={helpButton_onClick} />
 		</div>
 	);
@@ -202,6 +225,7 @@ const mapStateToProps = (state: AppState) => {
 	return {
 		themeId: state.settings.theme,
 		scrollbarSize: state.settings['style.scrollbarSize'],
+		fontFamily: state.settings['style.viewer.fontFamily'],
 	};
 };
 
