@@ -79,5 +79,7 @@ export default function() {
 		'switchProfile3',
 		'pasteAsText',
 		'showNoteProperties',
+		'convertNoteToMarkdown',
+		'toggleEditors',
 	];
 }
