@@ -2,23 +2,16 @@
 import { ElectronApplication } from '@playwright/test';
 import type { PageFunctionOn } from 'playwright-core/types/structs';
 import type * as ElectronType from 'electron';
+import retryOnFailure from './retryOnFailure';
 
 const evaluateWithRetry = async <ReturnType, Arg> (
 	app: ElectronApplication,
 	pageFunction: PageFunctionOn<typeof ElectronType, Arg, ReturnType>,
 	arg: Arg,
 ) => {
-	let lastError;
-	const maxRetries = 3;
-	for (let retryIndex = 0; retryIndex < maxRetries; retryIndex ++) {
-		try {
-			return await app.evaluate(pageFunction, arg);
-		} catch (error) {
-			console.error('app.evaluate failed:', error, `Retrying... ${retryIndex}/${maxRetries}`);
-			lastError = error;
-		}
-	}
-	throw lastError;
+	await retryOnFailure(async () => {
+		return await app.evaluate(pageFunction, arg);
+	}, { maxRetries: 3 });
 };
 
 export default evaluateWithRetry;
