@@ -21,10 +21,13 @@ export default defineConfig({
 	workers: process.env.CI ? 1 : undefined,
 
 	// Reporter to use. See https://playwright.dev/docs/test-reporters
-	reporter: process.env.CI ? 'line' : 'html',
+	reporter: process.env.CI ? [
+		['dot'], // Give realtime workflow progress in CI
+		['html'],
+	] : 'html',
 
 	// The CI machines can sometimes be very slow. Increase per-test timeout in CI.
-	timeout: process.env.CI ? 50_000 : 30_000, // milliseconds
+	timeout: process.env.CI ? 70_000 : 60_000, // milliseconds
 
 	// Shared settings for all the projects below. See https://playwright.dev/docs/api/class-testoptions.
 	use: {
