@@ -6,21 +6,28 @@
 import { AppState } from '../../app.reducer';
 import libStateToWhenClauseContext, { WhenClauseContextOptions } from '@joplin/lib/services/commands/stateToWhenClauseContext';
 import layoutItemProp from '../../gui/ResizableLayout/utils/layoutItemProp';
+import { defaultWindowId, stateUtils } from '@joplin/lib/reducer';
 
 export default function stateToWhenClauseContext(state: AppState, options: WhenClauseContextOptions = null) {
+	const windowId = options?.windowId ?? defaultWindowId;
+	const isMainWindow = windowId === defaultWindowId;
+	const windowState = stateUtils.windowStateById(state, windowId);
+	const isAltInstance = !!state.settings.altInstanceId;
+
 	return {
 		...libStateToWhenClauseContext(state, options),
 
 		// UI elements
-		markdownEditorVisible: !!state.settings['editor.codeView'] && !state.settings['isSafeMode'],
-		richTextEditorVisible: !state.settings['editor.codeView'] && !state.settings['isSafeMode'],
+		markdownEditorVisible: !!windowState.editorCodeView && !state.settings['isSafeMode'],
+		richTextEditorVisible: !windowState.editorCodeView && !state.settings['isSafeMode'],
 
-		markdownEditorPaneVisible: state.settings['editor.codeView'] && state.noteVisiblePanes.includes('editor'),
-		markdownViewerPaneVisible: state.settings['editor.codeView'] && state.noteVisiblePanes.includes('viewer'),
+		markdownEditorPaneVisible: windowState.editorCodeView && windowState.noteVisiblePanes.includes('editor'),
+		markdownViewerPaneVisible: windowState.editorCodeView && windowState.noteVisiblePanes.includes('viewer'),
 		modalDialogVisible: !!Object.keys(state.visibleDialogs).length,
 		gotoAnythingVisible: !!state.visibleDialogs['gotoAnything'],
-		sidebarVisible: !!state.mainLayout && layoutItemProp(state.mainLayout, 'sideBar', 'visible'),
-		noteListHasNotes: !!state.notes.length,
+		sidebarVisible: isMainWindow && !!state.mainLayout && layoutItemProp(state.mainLayout, 'sideBar', 'visible'),
+		noteListHasNotes: !!windowState.notes.length,
+		isAltInstance,
 
 		// Deprecated
 		sideBarVisible: !!state.mainLayout && layoutItemProp(state.mainLayout, 'sideBar', 'visible'),
