@@ -24,16 +24,18 @@ export interface DialogControl {
 	info(message: string): Promise<void>;
 	error(message: string): Promise<void>;
 	prompt(title: string, message: string, buttons?: PromptButtonSpec[], options?: PromptOptions): void;
+	promptForText(message: string): Promise<string>;
 	showMenu<IdType>(title: string, choices: MenuChoice<IdType>[]): Promise<IdType>;
 }
 
 export enum DialogType {
-	Prompt,
+	ButtonPrompt,
 	Menu,
+	TextInput,
 }
 
-export interface PromptDialogData {
-	type: DialogType;
+export interface ButtonDialogData {
+	type: DialogType.ButtonPrompt|DialogType.Menu;
 	key: string;
 	title: string;
 	message: string;
@@ -41,3 +43,13 @@ export interface PromptDialogData {
 	onDismiss: (()=> void)|null;
 }
 
+export interface TextInputDialogData {
+	type: DialogType.TextInput;
+	key: string;
+	message: string;
+	onSubmit: (text: string)=> void;
+	onDismiss: ()=> void;
+}
+
+export type DialogData = ButtonDialogData | TextInputDialogData;
+
