@@ -1,19 +1,16 @@
 import Logger from '@joplin/utils/Logger';
-import FingerprintScanner, { Errors } from 'react-native-fingerprint-scanner';
 import { _ } from '@joplin/lib/locale';
+import { authenticateAsync } from 'expo-local-authentication';
 
 const logger = Logger.create('biometricAuthenticate');
 
 export default async () => {
-	try {
-		logger.info('Authenticate...');
-		await FingerprintScanner.authenticate({ description: _('Verify your identity') });
-		logger.info('Authenticate done');
-	} catch (error) {
-		const errorName = (error as Errors).name;
+	logger.info('Authenticate...');
+	const result = await authenticateAsync({ promptMessage: _('Verify your identity') });
 
-		const errorMessage = error.message;
-		if (errorName === 'FingerprintScannerNotEnrolled' || errorName === 'FingerprintScannerNotAvailable') {
+	if (result.success === false) {
+		const errorName = result.error;
+		if (errorName === 'not_enrolled' || errorName === 'not_available') {
 			// In that case we skip the check because the device biometric unlock has been disabled
 			// by the user. It should be safe to skip the check since in order to disable it, they
 			// must have full access to the phone, and should have to enter their pin. Not skipping
@@ -26,13 +23,8 @@ export default async () => {
 
 			// errorMessage = _('Biometric unlock is not setup on the device. Please set it up in order to unlock Joplin. If the device is on lockout, consider switching it off and on to reset biometrics scanning.');
 		}
-
-		error.message = _('Could not verify your identity: %s', errorMessage);
-
-		logger.warn(error);
-
-		throw error;
-	} finally {
-		FingerprintScanner.release();
+		throw new Error(_('Could not verify your identity: %s', errorName));
 	}
+
+	logger.info('Authenticate done');
 };
