@@ -2,13 +2,11 @@ import * as React from 'react';
 import { PluginSettings } from '@joplin/lib/services/plugins/PluginService';
 import configScreenStyles from '../../configScreenStyles';
 import Setting from '@joplin/lib/models/Setting';
-import { Provider } from 'react-redux';
 import { Store } from 'redux';
-import { PaperProvider } from 'react-native-paper';
 import PluginStates from '../PluginStates';
 import { AppState } from '../../../../../utils/types';
 import { useCallback, useState } from 'react';
-import { MenuProvider } from 'react-native-popup-menu';
+import TestProviderStack from '../../../../testing/TestProviderStack';
 
 interface WrapperProps {
 	initialPluginSettings: PluginSettings;
@@ -29,19 +27,15 @@ const PluginStatesWrapper = (props: WrapperProps) => {
 	}, []);
 
 	return (
-		<Provider store={props.store}>
-			<MenuProvider>
-				<PaperProvider>
-					<PluginStates
-						styles={styles}
-						themeId={Setting.THEME_LIGHT}
-						updatePluginStates={updatePluginStates}
-						pluginSettings={pluginSettings}
-						shouldShowBasedOnSearchQuery={shouldShowBasedOnSettingSearchQuery}
-					/>
-				</PaperProvider>
-			</MenuProvider>
-		</Provider>
+		<TestProviderStack store={props.store}>
+			<PluginStates
+				styles={styles}
+				themeId={Setting.THEME_LIGHT}
+				updatePluginStates={updatePluginStates}
+				pluginSettings={pluginSettings}
+				shouldShowBasedOnSearchQuery={shouldShowBasedOnSettingSearchQuery}
+			/>
+		</TestProviderStack>
 	);
 };
 
