@@ -8,7 +8,7 @@ export interface CustomSettingSection {
 }
 
 // eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
-export type UpdateSettingValueCallback = (key: string, value: any)=> Promise<void>;
+export type UpdateSettingValueCallback = (key: string, value: any)=> void|Promise<void>;
 
 export interface PluginStatusRecord {
 	[pluginId: string]: boolean;
