@@ -3,9 +3,6 @@ import { themeStyle } from '../components/global-style';
 export default (themeId: number) => {
 	const theme = themeStyle(themeId);
 	return {
-		root: {
-			flex: 1,
-			backgroundColor: theme.backgroundColor,
-		},
+		root: theme.rootStyle,
 	};
 };
