@@ -1,11 +1,12 @@
 import Setting from '@joplin/lib/models/Setting';
 import CommandService, { CommandDeclaration, CommandRuntime } from '@joplin/lib/services/CommandService';
-import stateToWhenClauseContext from '@joplin/lib/services/commands/stateToWhenClauseContext';
 import { AppState } from './types';
 import { Store } from 'redux';
 import editorCommandDeclarations from '../components/NoteEditor/commandDeclarations';
+import noteCommands from '../components/screens/Note/commands';
 import globalCommands from '../commands';
 import libCommands from '@joplin/lib/commands';
+import stateToWhenClauseContext from '../services/commands/stateToWhenClauseContext';
 
 interface CommandSpecification {
 	declaration: CommandDeclaration;
@@ -25,6 +26,9 @@ const initializeCommandService = (store: Store<AppState, any>) => {
 	for (const declaration of editorCommandDeclarations) {
 		CommandService.instance().registerDeclaration(declaration);
 	}
+	for (const command of noteCommands) {
+		CommandService.instance().registerDeclaration(command.declaration);
+	}
 	registerCommands(globalCommands);
 	registerCommands(libCommands);
 };
