@@ -85,7 +85,12 @@ const shimInitShared = () => {
 
 	shim.injectedJs = function(name) {
 		if (!(name in injectedJs)) throw new Error(`Cannot find injectedJs file (add it to "injectedJs" object): ${name}`);
-		return injectedJs[name as keyof typeof injectedJs];
+		return injectedJs[name as keyof typeof injectedJs].js;
+	};
+
+	shim.injectedCss = function(name) {
+		if (!(name in injectedJs)) throw new Error(`Cannot find CSS file (add it to "injectedJs" object): ${name}`);
+		return injectedJs[name as keyof typeof injectedJs].css;
 	};
 
 	shim.setTimeout = (fn, interval) => {
