@@ -2,15 +2,14 @@ import reducer from '@joplin/lib/reducer';
 import { createStore } from 'redux';
 import appDefaultState from '../appDefaultState';
 import Setting from '@joplin/lib/models/Setting';
+import { AppState } from '../types';
 
-const defaultState = {
-	...appDefaultState,
-	// Mocking theme in the default state is necessary to prevent "Theme not set!" warnings.
-	settings: { theme: Setting.THEME_LIGHT },
-};
-
-const testReducer = (state = defaultState, action: unknown) => {
-	return reducer(state, action);
+const testReducer = (state: AppState|undefined, action: unknown): AppState => {
+	state ??= {
+		...appDefaultState,
+		settings: Setting.toPlainObject(),
+	};
+	return { ...state, ...reducer(state, action) };
 };
 
 const createMockReduxStore = () => {
