@@ -12,6 +12,8 @@ const createEditorControl = (initialText: string) => {
 		onEvent: _event => {},
 		onLogMessage: _message => {},
 		onPasteFile: null,
+		resolveImageSrc: (src)=>Promise.resolve(src),
+		onLocalize: input=>input,
 	});
 };
 
