@@ -1,18 +1,18 @@
 import { Command, TextSelection } from 'prosemirror-state';
-import uslug from '@joplin/fork-uslug/lib/uslug';
-import { NodeType } from 'prosemirror-model';
 import { focus } from '@joplin/lib/utils/focusHandler';
+import forEachHeading from './forEachHeading';
+
+const jumpToHash = (targetHash: string): Command => (state, dispatch, view) => {
+	if (targetHash.startsWith('#')) {
+		targetHash = targetHash.substring(1);
+	}
 
-const jumpToHash = (targetHash: string, headingType: NodeType): Command => (state, dispatch, view) => {
 	let targetHeaderPos: number|null = null;
-	state.doc.descendants((node, pos) => {
-		if (node.type === headingType) {
-			const hash = uslug(node.textContent);
-			if (hash === targetHash) {
-				// Subtract one to move the selection to the end of
-				// the node:
-				targetHeaderPos = pos + node.nodeSize - 1;
-			}
+	forEachHeading(view.state.doc, (node, hash, pos) => {
+		if (hash === targetHash) {
+			// Subtract one to move the selection to the end of
+			// the node:
+			targetHeaderPos = pos + node.nodeSize - 1;
 		}
 
 		return targetHeaderPos !== null;
