@@ -9,7 +9,7 @@ import { MarkupToHtml } from '@joplin/renderer';
 import { NoteEntity, ResourceEntity, ResourceLocalStateEntity } from '../database/types';
 import { contentScriptsToRendererRules } from '../plugins/utils/loadContentScripts';
 import { basename, friendlySafeFilename, rtrimSlashes, dirname } from '../../path-utils';
-import htmlpack from '@joplin/htmlpack';
+import packToString from '@joplin/htmlpack/packToString';
 const { themeStyle } = require('../../theme');
 const { escapeHtml } = require('../../string-utils.js');
 import { assetsToHeaders } from '@joplin/renderer';
@@ -19,6 +19,7 @@ import Logger from '@joplin/utils/Logger';
 import { parseRenderedNoteMetadata } from './utils';
 import ResourceLocalState from '../../models/ResourceLocalState';
 import { ResourceInfos } from '@joplin/renderer/types';
+import { fromFilename } from '../../mime-utils';
 
 const logger = Logger.create('InteropService_Exporter_Html');
 
@@ -138,13 +139,11 @@ export default class InteropService_Exporter_Html extends InteropService_Exporte
 			if (metadata.printTitle && item.title) noteContent.push(`<div class="exported-note-title">${escapeHtml(item.title)}</div>`);
 			if (result.html) noteContent.push(result.html);
 
-			const libRootPath = dirname(dirname(__dirname));
-
 			// We need to export all the plugin assets too and refer them from the header
 			// The source path is a bit hard-coded but shouldn't change.
 			for (let i = 0; i < result.pluginAssets.length; i++) {
 				const asset = result.pluginAssets[i];
-				const filePath = asset.pathIsAbsolute ? asset.path : `${libRootPath}/node_modules/@joplin/renderer/assets/${asset.name}`;
+				const filePath = asset.pathIsAbsolute ? asset.path : `${Setting.value('pluginAssetDir')}/${asset.name}`;
 				if (!(await shim.fsDriver().exists(filePath))) {
 					logger.warn(`File does not exist and cannot be exported: ${filePath}`);
 				} else {
@@ -175,8 +174,12 @@ export default class InteropService_Exporter_Html extends InteropService_Exporte
 		}
 	}
 
-	// eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
 	public async processResource(resource: ResourceEntity, filePath: string) {
+		if (!this.resourceDir_) return;
+		if (!await shim.fsDriver().exists(this.resourceDir_)) {
+			await shim.fsDriver().mkdir(this.resourceDir_);
+		}
+
 		const destResourcePath = `${this.resourceDir_}/${basename(filePath)}`;
 		await shim.fsDriver().copy(filePath, destResourcePath);
 		const localState: ResourceLocalStateEntity = await ResourceLocalState.load(resource.id);
@@ -188,10 +191,37 @@ export default class InteropService_Exporter_Html extends InteropService_Exporte
 
 	public async close() {
 		if (this.packIntoSingleFile_) {
-			const tempFilePath = `${this.filePath_}.tmp`;
-			await shim.fsDriver().move(this.filePath_, tempFilePath);
-			await htmlpack(tempFilePath, this.filePath_);
-			await shim.fsDriver().remove(tempFilePath);
+			const mainHtml = await shim.fsDriver().readFile(this.filePath_, 'utf8');
+			const resolveToAllowedDir = (path: string) => {
+				// TODO: Enable this for all platforms -- at present, this is mobile-only.
+				const restrictToDestDir = !!shim.mobilePlatform();
+				if (restrictToDestDir) {
+					return shim.fsDriver().resolveRelativePathWithinDir(this.destDir_, path);
+				} else {
+					return shim.fsDriver().resolve(this.destDir_, path);
+				}
+			};
+			const packedHtml = await packToString(
+				this.destDir_,
+				mainHtml,
+				{
+					exists: (path) => {
+						path = resolveToAllowedDir(path);
+						return shim.fsDriver().exists(path);
+					},
+					readFileDataUri: async (path) => {
+						path = resolveToAllowedDir(path);
+						const mimeType = fromFilename(path);
+						const content = await shim.fsDriver().readFile(path, 'base64');
+						return `data:${mimeType};base64,${content}`;
+					},
+					readFileText: (path) => {
+						path = resolveToAllowedDir(path);
+						return shim.fsDriver().readFile(path, 'utf8');
+					},
+				},
+			);
+			await shim.fsDriver().writeFile(this.filePath_, packedHtml, 'utf8');
 
 			for (const d of this.createdDirs_) {
 				await shim.fsDriver().remove(d);
