@@ -815,7 +815,7 @@ export default class SearchEngine {
 					};
 				});
 
-				if (!queryHasFilters) {
+				if (!queryHasFilters && Setting.value('ocr.searchInExtractedContent')) {
 					const toSearch = parsedQuery.allTerms.map(t => t.value).join(' ');
 
 					let itemRows: ProcessResultsRow[] = [];
