@@ -1,6 +1,11 @@
-import { MarkupLanguage } from './MarkupToHtml';
 import { Options as NoteStyleOptions } from './noteStyle';
 
+export enum MarkupLanguage {
+	Markdown = 1,
+	Html = 2,
+	Any = 3,
+}
+
 export type ItemIdToUrlHandler = (resourceId: string, urlParameters?: string)=> string;
 
 interface ResourceEntity {
@@ -35,6 +40,7 @@ export interface FsDriver {
 export interface RenderOptions {
 	contentMaxWidth?: number;
 	scrollbarSize?: number;
+	baseFontFamily?: string;
 	bodyOnly?: boolean;
 	splitted?: boolean;
 	enableLongPress?: boolean;
@@ -66,7 +72,6 @@ export interface RenderOptions {
 
 	resources?: ResourceInfos;
 
-	onResourceLoaded?: ()=> void;
 	editPopupFiletypes?: string[];
 	createEditPopupSyntax?: string;
 	destroyEditPopupSyntax?: string;
