@@ -42,6 +42,10 @@ const defaultEnvValues: EnvVariables = {
 
 	DELTA_INCLUDES_ITEMS: true,
 
+	// Whether or not to allow users logging in with a username/password combo.
+	// If this is disabled, a SAML-based login flow must be configured.
+	LOCAL_AUTH_ENABLED: true,
+
 	// ==================================================
 	// URL config
 	// ==================================================
@@ -149,6 +153,22 @@ const defaultEnvValues: EnvVariables = {
 	LDAP_2_BIND_PW: '', // used for user search - leave empty if ldap server allows anonymous bind
 	LDAP_2_TLS_CA_FILE: '', // used for self-signed certificate with ldaps - leave empty if using ldap or server uses CA-issued certificate
 
+	// ==================================================
+	// SAML configuration
+	// ==================================================
+
+	SAML_ENABLED: false,
+	SAML_IDP_CONFIG_FILE: '', // Config file for the Identity Provider. Should point to an XML file generated by the Identity Provider.
+	SAML_SP_CONFIG_FILE: '', // Config file for the Service Provider (Joplin, in this case). Should point to an XML file generated by the Identity Provider.
+	SAML_ORGANIZATION_DISPLAY_NAME: '', // The name of the organization to display on the login screen. Optional.
+
+	// ==================================================
+	// Transcribe Server
+	// ==================================================
+
+	TRANSCRIBE_ENABLED: false,
+	TRANSCRIBE_API_KEY: '',
+	TRANSCRIBE_BASE_URL: '',
 };
 
 export interface EnvVariables {
@@ -241,6 +261,17 @@ export interface EnvVariables {
 	LDAP_2_BIND_DN: string;
 	LDAP_2_BIND_PW: string;
 	LDAP_2_TLS_CA_FILE: string;
+
+	SAML_ENABLED: boolean;
+	SAML_IDP_CONFIG_FILE: string;
+	SAML_SP_CONFIG_FILE: string;
+	SAML_ORGANIZATION_DISPLAY_NAME: string;
+
+	LOCAL_AUTH_ENABLED: boolean;
+
+	TRANSCRIBE_ENABLED: boolean;
+	TRANSCRIBE_API_KEY: string;
+	TRANSCRIBE_BASE_URL: string;
 }
 
 const parseBoolean = (s: string): boolean => {
