@@ -145,6 +145,13 @@ export interface LdapConfig {
 	tlsCaFile: string;
 }
 
+export interface SamlConfig {
+	enabled: boolean;
+	identityProviderConfigFile: string;
+	serviceProviderConfigFile: string;
+	organizationDisplayName: string;
+}
+
 export interface Config extends EnvVariables {
 	appVersion: string;
 	joplinServerVersion: string; // May be different from appVersion, if this is a fork of JS
@@ -181,6 +188,7 @@ export interface Config extends EnvVariables {
 	itemSizeHardLimit: number;
 	maxTimeDrift: number;
 	ldap: LdapConfig[];
+	saml: SamlConfig;
 }
 
 export enum HttpMethod {
@@ -202,3 +210,9 @@ export type KoaNext = ()=> Promise<void>;
 export interface CommandContext {
 	models: Models;
 }
+
+export type SamlRelayState = 'web-login' | 'app-login' | null;
+export interface SamlPostResponse {
+	SAMLResponse: string;
+	RelayState?: SamlRelayState;
+}
