@@ -95,7 +95,9 @@ const parseHtml = (html: string) => {
 				attrHtml.push(`${n}=${escapedValue}`);
 			}
 
-			output.push(`<${name} ${attrHtml.join(' ')}${closingSign}`);
+			const closingSpace = isSelfClosingTag(name) || !!attrHtml.length ? ' ' : '';
+
+			output.push(`<${name}${attrHtml.length ? ` ${attrHtml.join(' ')}` : ''}${closingSpace}${closingSign}`);
 		},
 
 		ontext: (decodedText: string) => {
@@ -159,13 +161,13 @@ const processToken = (token: any, output: string[], context: Context): void => {
 		context.inFence = true;
 		content.push(`\`\`\`${token.info || ''}\n`);
 	} else if (type === 'html_block') {
-		contentProcessed = true,
+		contentProcessed = true;
 		content.push(parseHtml(token.content.trim()));
 	} else if (type === 'html_inline') {
-		contentProcessed = true,
+		contentProcessed = true;
 		content.push(parseHtml(token.content.trim()));
 	} else if (type === 'code_inline') {
-		contentProcessed = true,
+		contentProcessed = true;
 		content.push(`\`${token.content}\``);
 	} else if (type === 'code_block') {
 		contentProcessed = true;
