@@ -1,5 +1,5 @@
 import Logger from '@joplin/utils/Logger';
-import { BaseQueue, JobWithData, WorkHandler } from '../types';
+import { BaseQueue, ContentStorage, JobWithData, WorkHandler } from '../types';
 
 const logger = Logger.create('JobProcessor');
 
@@ -10,10 +10,12 @@ export default class JobProcessor {
 	private checkInteval = 5000;
 	private currentJob: JobWithData | null = null;
 	private workHandler: WorkHandler;
+	private contentStorage: ContentStorage;
 
-	public constructor(queue: BaseQueue, workHandler: WorkHandler, checkInterval?: number) {
+	public constructor(queue: BaseQueue, workHandler: WorkHandler, contentStorage: ContentStorage, checkInterval?: number) {
 		this.queue = queue;
 		this.workHandler = workHandler;
+		this.contentStorage = contentStorage;
 		this.checkInteval = checkInterval ?? 5000;
 		logger.info('Created JobProcessor');
 	}
@@ -48,6 +50,7 @@ export default class JobProcessor {
 		logger.info(`Processing job ${this.currentJob.id}`);
 		const transcription = await this.workHandler.run(this.currentJob.data.filePath);
 		await this.queue.complete(this.currentJob.id, { result: transcription });
+		await this.contentStorage.remove(this.currentJob.data.filePath);
 	}
 
 	public async runOnce() {
@@ -58,6 +61,9 @@ export default class JobProcessor {
 			const e = error as Error;
 			if (this.currentJob) {
 				await this.queue.fail(this.currentJob.id, e);
+				if (this.queue.hasJobFailedTooManyTimes(this.currentJob)) {
+					await this.contentStorage.remove(this.currentJob.data.filePath);
+				}
 			}
 		} finally {
 			this.currentJob = null;
