@@ -218,6 +218,25 @@ function isOrderedList(e) {
   return e.style && e.style.listStyleType === 'decimal';
 }
 
+// `content` should be the part of the item after the list marker (e.g. "[ ] test" in "- [ ] test").
+const removeListItemLeadingNewlines = (content) => {
+  const itemStartRegex = /(^\[[Xx ]\]|^)([ \n]+)/;
+  const startingSpaceMatch = content.match(itemStartRegex);
+  if (!startingSpaceMatch) return content;
+
+  const checkbox = startingSpaceMatch[1];
+  const space = startingSpaceMatch[2];
+  if (space.includes('\n')) {
+    content = content.replace(itemStartRegex, `${checkbox} `);
+  }
+
+  return content;
+};
+
+const isEmptyTaskListItem = (content) => {
+  return content.match(/^\[[xX \][ \n\t]*$/);
+};
+
 rules.listItem = {
   filter: 'li',
 
@@ -266,7 +285,16 @@ rules.listItem = {
           prefix = indexStr + '.' + ' '.repeat(3 - indexStr.length)
         }
       }
-    } 
+    }
+
+    // Prevent the item from starting with a blank line (which breaks rendering)
+    content = removeListItemLeadingNewlines(content);
+
+    // Prevent the item from being empty (which also prevents the item from rendering as a list
+    // item).
+    if (isEmptyTaskListItem(content)) {
+      content += '&nbsp;';
+    }
 
     return (
       prefix + content + (node.nextSibling && !/\n$/.test(content) ? '\n' : '')
@@ -599,7 +627,7 @@ function imageMarkdownFromNode(node, options = null) {
 
   return imageMarkdownFromAttributes({
     alt: node.alt,
-    src: node.getAttribute('src'),
+    src: node.getAttribute('src') || node.getAttribute('data-src'),
     title: node.title,
   });
 }
